.. django-uswds-forms documentation master file, created by
   sphinx-quickstart on Tue May  9 10:15:27 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to django-uswds-forms's documentation!
==============================================

Welcome to the `django-uswds-forms <https://github.com/18F/django-uswds-forms>`_ documentation!

This package provides `Django Forms <https://docs.djangoproject.com/en/1.11/topics/forms/#the-django-form-class>`_
integration with the `U.S. Web Design Standards <https://standards.usa.gov/>`_.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   introduction
   quickstart
   reference
   developing

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
